@@ -17,6 +17,7 @@ from enum import IntEnum
 from io import TextIOBase
 from pathlib import Path
 from typing import (
+    TYPE_CHECKING,
     Any,
     DefaultDict,
     Dict,
@@ -29,12 +30,11 @@ from typing import (
     cast,
 )
 from urllib.parse import ParseResult, urlparse
-from warnings import warn
 
 import argcomplete
 import black
 import toml
-from pydantic import BaseModel, root_validator, validator
+from pydantic import BaseModel
 
 from datamodel_code_generator import (
     DEFAULT_BASE_CLASS,
@@ -54,6 +54,13 @@ from datamodel_code_generator.format import (
 from datamodel_code_generator.parser import LiteralType
 from datamodel_code_generator.reference import is_url
 from datamodel_code_generator.types import StrictTypes
+from datamodel_code_generator.util import (
+    PYDANTIC_V2,
+    ConfigDict,
+    Model,
+    field_validator,
+    model_validator,
+)
 
 
 class Exit(IntEnum):
@@ -281,7 +288,7 @@ arg_parser.add_argument(
 arg_parser.add_argument(
     '--use-default-kwarg',
     action='store_true',
-    help="Use `default=` instead of a positional argument for Fields that have default values.",
+    help='Use `default=` instead of a positional argument for Fields that have default values.',
 )
 
 arg_parser.add_argument(
@@ -293,17 +300,17 @@ arg_parser.add_argument(
 
 arg_parser.add_argument(
     '--keep-model-order',
-    help='Keep generated models\' order',
+    help="Keep generated models' order",
     action='store_true',
     default=None,
 )
 
 arg_parser.add_argument(
-    "--collapse-root-models",
+    '--collapse-root-models',
     action='store_true',
     default=None,
-    help="Models generated with a root-type field will be merged"
-    "into the models using that root-type model",
+    help='Models generated with a root-type field will be merged'
+    'into the models using that root-type model',
 )
 
 
@@ -312,7 +319,14 @@ arg_parser.add_argument(
     help='Parse enum field as literal. '
     'all: all enum field type are Literal. '
     'one: field type is Literal when an enum has only one possible value',
-    choices=[l.value for l in LiteralType],
+    choices=[lt.value for lt in LiteralType],
+    default=None,
+)
+
+arg_parser.add_argument(
+    '--use-one-literal-as-default',
+    help='Use one literal as default value for one literal field',
+    action='store_true',
     default=None,
 )
 
@@ -339,13 +353,13 @@ arg_parser.add_argument(
 
 arg_parser.add_argument(
     '--special-field-name-prefix',
-    help='Set field name prefix when first character can\'t be used as Python field name (default:  `field`)',
+    help="Set field name prefix when first character can't be used as Python field name (default:  `field`)",
     default=None,
 )
 
 arg_parser.add_argument(
     '--remove-special-field-name-prefix',
-    help='Remove field name prefix when first character can\'t be used as Python field name',
+    help="Remove field name prefix when first character can't be used as Python field name",
     action='store_true',
     default=None,
 )
@@ -370,6 +384,20 @@ arg_parser.add_argument(
     default=None,
 )
 
+arg_parser.add_argument(
+    '--use-operation-id-as-name',
+    help='use operation id of OpenAPI as class names of models',
+    action='store_true',
+    default=None,
+)
+
+arg_parser.add_argument(
+    '--use-unique-items-as-set',
+    help='define field type as `set` when the field attribute has `uniqueItems`',
+    action='store_true',
+    default=None,
+)
+
 arg_parser.add_argument(
     '--custom-template-dir', help='Custom template directory', type=str
 )
@@ -398,11 +426,11 @@ arg_parser.add_argument(
 )
 
 arg_parser.add_argument(
-    "--use-double-quotes",
+    '--use-double-quotes',
     action='store_true',
     default=None,
-    help="Model generated with double quotes. Single quotes or "
-    "your black config skip_string_normalization value will be used without this option.",
+    help='Model generated with double quotes. Single quotes or '
+    'your black config skip_string_normalization value will be used without this option.',
 )
 
 arg_parser.add_argument(
@@ -417,38 +445,92 @@ arg_parser.add_argument(
 arg_parser.add_argument(
     '--disable-warnings', help='disable warnings', action='store_true', default=None
 )
+arg_parser.add_argument(
+    '--custom-file-header', help='Custom file header', type=str, default=None
+)
+
+arg_parser.add_argument(
+    '--custom-file-header-path',
+    help='Custom file header file path',
+    default=None,
+    type=str,
+)
+
+
 arg_parser.add_argument('--version', help='show version', action='store_true')
 
 
 class Config(BaseModel):
-    class Config:
-        # validate_assignment = True
-        # Pydantic 1.5.1 doesn't support validate_assignment correctly
-        arbitrary_types_allowed = (TextIOBase,)
+    if PYDANTIC_V2:
+        model_config = ConfigDict(arbitrary_types_allowed=True)
 
-    @validator("aliases", "extra_template_data", pre=True)
+        def get(self, item: str) -> Any:
+            return getattr(self, item)
+
+        def __getitem__(self, item: str) -> Any:
+            return self.get(item)
+
+        def __setitem__(self, key: str, value: Any) -> None:
+            setattr(self, key, value)
+
+        if TYPE_CHECKING:
+
+            @classmethod
+            def get_fields(cls) -> Dict[str, Any]:
+                ...
+
+        else:
+
+            @classmethod
+            def parse_obj(cls: type[Model], obj: Any) -> Model:
+                return cls.model_validate(obj)
+
+            @classmethod
+            def get_fields(cls) -> Dict[str, Any]:
+                return cls.model_fields
+
+    else:
+
+        class Config:
+            # validate_assignment = True
+            # Pydantic 1.5.1 doesn't support validate_assignment correctly
+            arbitrary_types_allowed = (TextIOBase,)
+
+        if not TYPE_CHECKING:
+
+            @classmethod
+            def get_fields(cls) -> Dict[str, Any]:
+                return cls.__fields__
+
+    @field_validator('aliases', 'extra_template_data', mode='before')
     def validate_file(cls, value: Any) -> Optional[TextIOBase]:
         if value is None or isinstance(value, TextIOBase):
             return value
-        return cast(TextIOBase, Path(value).expanduser().resolve().open("rt"))
+        return cast(TextIOBase, Path(value).expanduser().resolve().open('rt'))
 
-    @validator("input", "output", "custom_template_dir", pre=True)
+    @field_validator(
+        'input',
+        'output',
+        'custom_template_dir',
+        'custom_file_header_path',
+        mode='before',
+    )
     def validate_path(cls, value: Any) -> Optional[Path]:
         if value is None or isinstance(value, Path):
             return value  # pragma: no cover
         return Path(value).expanduser().resolve()
 
-    @validator('url', pre=True)
+    @field_validator('url', mode='before')
     def validate_url(cls, value: Any) -> Optional[ParseResult]:
         if isinstance(value, str) and is_url(value):  # pragma: no cover
             return urlparse(value)
         elif value is None:  # pragma: no cover
             return None
         raise Error(
-            f'This protocol doesn\'t support only http/https. --input={value}'
+            f"This protocol doesn't support only http/https. --input={value}"
         )  # pragma: no cover
 
-    @root_validator
+    @model_validator(mode='after')
     def validate_use_generic_container_types(
         cls, values: Dict[str, Any]
     ) -> Dict[str, Any]:
@@ -456,24 +538,32 @@ class Config(BaseModel):
             target_python_version: PythonVersion = values['target_python_version']
             if target_python_version == target_python_version.PY_36:
                 raise Error(
-                    f"`--use-generic-container-types` can not be used with `--target-python_version` {target_python_version.PY_36.value}.\n"  # type: ignore
-                    " The version will be not supported in a future version"
+                    f'`--use-generic-container-types` can not be used with `--target-python_version` {target_python_version.PY_36.value}.\n'
+                    ' The version will be not supported in a future version'
                 )
         return values
 
-    @root_validator
+    @model_validator(mode='after')
     def validate_original_field_name_delimiter(
         cls, values: Dict[str, Any]
     ) -> Dict[str, Any]:
         if values.get('original_field_name_delimiter') is not None:
             if not values.get('snake_case_field'):
                 raise Error(
-                    "`--original-field-name-delimiter` can not be used without `--snake-case-field`."
+                    '`--original-field-name-delimiter` can not be used without `--snake-case-field`.'
                 )
         return values
 
+    @model_validator(mode='after')
+    def validate_custom_file_header(cls, values: Dict[str, Any]) -> Dict[str, Any]:
+        if values.get('custom_file_header') and values.get('custom_file_header_path'):
+            raise Error(
+                '`--custom_file_header_path` can not be used with `--custom_file_header`.'
+            )  # pragma: no cover
+        return values
+
     # Pydantic 1.5.1 doesn't support each_item=True correctly
-    @validator('http_headers', pre=True)
+    @field_validator('http_headers', mode='before')
     def validate_http_headers(cls, value: Any) -> Optional[List[Tuple[str, str]]]:
         def validate_each_item(each_item: Any) -> Tuple[str, str]:
             if isinstance(each_item, str):  # pragma: no cover
@@ -490,10 +580,9 @@ class Config(BaseModel):
             return [validate_each_item(each_item) for each_item in value]
         return value  # pragma: no cover
 
-    @root_validator()
+    @model_validator(mode='after')
     def validate_root(cls, values: Dict[str, Any]) -> Dict[str, Any]:
         values = cls._validate_use_annotated(values)
-        values = cls._validate_use_union_operator(values)
         return cls._validate_base_class(values)
 
     @classmethod
@@ -502,21 +591,6 @@ class Config(BaseModel):
             values['field_constraints'] = True
         return values
 
-    @classmethod
-    def _validate_use_union_operator(cls, values: Dict[str, Any]) -> Dict[str, Any]:
-        if values.get('use_union_operator'):
-            target_python_version: PythonVersion = PythonVersion(
-                values.get('target_python_version', PythonVersion.PY_37.value)
-            )
-            if not target_python_version.has_union_operator:
-                if not values.get('disable_warnings'):
-                    warn(
-                        f"`--use-union-operator` can not be used with `--target-python_version` {target_python_version.value}.\n"
-                        f"`--target-python_version` {PythonVersion.PY_310.value} will be used."
-                    )
-                values['target_python_version'] = PythonVersion.PY_310
-        return values
-
     @classmethod
     def _validate_base_class(cls, values: Dict[str, Any]) -> Dict[str, Any]:
         if 'base_class' not in values and 'output_model_type' in values:
@@ -524,21 +598,21 @@ class Config(BaseModel):
                 values['base_class'] = ''
         return values
 
-    input: Optional[Union[Path, str]]
+    input: Optional[Union[Path, str]] = None
     input_file_type: InputFileType = InputFileType.Auto
     output_model_type: DataModelType = DataModelType.PydanticBaseModel
-    output: Optional[Path]
+    output: Optional[Path] = None
     debug: bool = False
     disable_warnings: bool = False
     target_python_version: PythonVersion = PythonVersion.PY_37
     base_class: str = DEFAULT_BASE_CLASS
-    custom_template_dir: Optional[Path]
-    extra_template_data: Optional[TextIOBase]
+    custom_template_dir: Optional[Path] = None
+    extra_template_data: Optional[TextIOBase] = None
     validation: bool = False
     field_constraints: bool = False
     snake_case_field: bool = False
     strip_default_none: bool = False
-    aliases: Optional[TextIOBase]
+    aliases: Optional[TextIOBase] = None
     disable_timestamp: bool = False
     enable_version_header: bool = False
     allow_population_by_field_name: bool = False
@@ -553,6 +627,7 @@ class Config(BaseModel):
     reuse_model: bool = False
     encoding: str = DEFAULT_ENCODING
     enum_field_as_literal: Optional[LiteralType] = None
+    use_one_literal_as_default: bool = False
     set_default_enum_member: bool = False
     use_subclass_enum: bool = False
     strict_nullable: bool = False
@@ -569,6 +644,8 @@ class Config(BaseModel):
     openapi_scopes: Optional[List[OpenAPIScope]] = [OpenAPIScope.Schemas]
     wrap_string_literal: Optional[bool] = None
     use_title_as_name: bool = False
+    use_operation_id_as_name: bool = False
+    use_unique_items_as_set: bool = False
     http_headers: Optional[Sequence[Tuple[str, str]]] = None
     http_ignore_tls: bool = False
     use_annotated: bool = False
@@ -580,13 +657,16 @@ class Config(BaseModel):
     remove_special_field_name_prefix: bool = False
     capitalise_enum_members: bool = False
     keep_model_order: bool = False
+    custom_file_header: Optional[str] = None
+    custom_file_header_path: Optional[Path] = None
 
     def merge_args(self, args: Namespace) -> None:
         set_args = {
-            f: getattr(args, f) for f in self.__fields__ if getattr(args, f) is not None
+            f: getattr(args, f)
+            for f in self.get_fields()
+            if getattr(args, f) is not None
         }
         set_args = self._validate_use_annotated(set_args)
-        set_args = self._validate_use_union_operator(set_args)
         set_args = self._validate_base_class(set_args)
         parsed_args = self.parse_obj(set_args)
         for field_name in set_args:
@@ -611,7 +691,7 @@ def main(args: Optional[Sequence[str]] = None) -> Exit:
         exit(0)
 
     root = black_find_project_root((Path().resolve(),))
-    pyproject_toml_path = root / "pyproject.toml"
+    pyproject_toml_path = root / 'pyproject.toml'
     if pyproject_toml_path.is_file():
         pyproject_toml: Dict[str, Any] = {
             k.replace('-', '_'): v
@@ -662,7 +742,7 @@ def main(args: Optional[Sequence[str]] = None) -> Exit:
                     data, object_hook=lambda d: defaultdict(dict, **d)
                 )
             except json.JSONDecodeError as e:
-                print(f"Unable to load extra template data: {e}", file=sys.stderr)
+                print(f'Unable to load extra template data: {e}', file=sys.stderr)
                 return Exit.ERROR
 
     if config.aliases is None:
@@ -672,7 +752,7 @@ def main(args: Optional[Sequence[str]] = None) -> Exit:
             try:
                 aliases = json.load(data)
             except json.JSONDecodeError as e:
-                print(f"Unable to load alias mapping: {e}", file=sys.stderr)
+                print(f'Unable to load alias mapping: {e}', file=sys.stderr)
                 return Exit.ERROR
         if not isinstance(aliases, dict) or not all(
             isinstance(k, str) and isinstance(v, str) for k, v in aliases.items()
@@ -712,6 +792,7 @@ def main(args: Optional[Sequence[str]] = None) -> Exit:
             reuse_model=config.reuse_model,
             encoding=config.encoding,
             enum_field_as_literal=config.enum_field_as_literal,
+            use_one_literal_as_default=config.use_one_literal_as_default,
             set_default_enum_member=config.set_default_enum_member,
             use_subclass_enum=config.use_subclass_enum,
             strict_nullable=config.strict_nullable,
@@ -726,6 +807,8 @@ def main(args: Optional[Sequence[str]] = None) -> Exit:
             openapi_scopes=config.openapi_scopes,
             wrap_string_literal=config.wrap_string_literal,
             use_title_as_name=config.use_title_as_name,
+            use_operation_id_as_name=config.use_operation_id_as_name,
+            use_unique_items_as_set=config.use_unique_items_as_set,
             http_headers=config.http_headers,
             http_ignore_tls=config.http_ignore_tls,
             use_annotated=config.use_annotated,
@@ -738,6 +821,8 @@ def main(args: Optional[Sequence[str]] = None) -> Exit:
             remove_special_field_name_prefix=config.remove_special_field_name_prefix,
             capitalise_enum_members=config.capitalise_enum_members,
             keep_model_order=config.keep_model_order,
+            custom_file_header=config.custom_file_header,
+            custom_file_header_path=config.custom_file_header_path,
         )
         return Exit.OK
     except InvalidClassNameError as e:
