@@ -21,26 +21,44 @@ from typing import (
 from warnings import warn
 
 from jinja2 import Environment, FileSystemLoader, Template
-from pydantic import BaseModel
+from pydantic import Field
 
-from datamodel_code_generator import cached_property
-from datamodel_code_generator.imports import IMPORT_ANNOTATED, IMPORT_OPTIONAL, Import
+from datamodel_code_generator.imports import (
+    IMPORT_ANNOTATED,
+    IMPORT_ANNOTATED_BACKPORT,
+    IMPORT_OPTIONAL,
+    IMPORT_UNION,
+    Import,
+)
 from datamodel_code_generator.reference import Reference, _BaseModel
-from datamodel_code_generator.types import DataType, Nullable, chain_as_tuple
+from datamodel_code_generator.types import (
+    ANY,
+    NONE,
+    UNION_PREFIX,
+    DataType,
+    Nullable,
+    chain_as_tuple,
+    get_optional_type,
+)
+from datamodel_code_generator.util import PYDANTIC_V2, ConfigDict, cached_property
 
 TEMPLATE_DIR: Path = Path(__file__).parents[0] / 'template'
 
-OPTIONAL: str = 'Optional'
-
 ALL_MODEL: str = '#all#'
 
 
 class ConstraintsBase(_BaseModel):
+    unique_items: Optional[bool] = Field(None, alias='uniqueItems')
     _exclude_fields: ClassVar[Set[str]] = {'has_constraints'}
+    if PYDANTIC_V2:
+        model_config = ConfigDict(
+            arbitrary_types_allowed=True, ignored_types=(cached_property,)
+        )
+    else:
 
-    class Config:
-        arbitrary_types_allowed = True
-        keep_untouched = (cached_property,)
+        class Config:
+            arbitrary_types_allowed = True
+            keep_untouched = (cached_property,)
 
     @cached_property
     def has_constraints(self) -> bool:
@@ -48,10 +66,10 @@ class ConstraintsBase(_BaseModel):
 
 
 class DataModelFieldBase(_BaseModel):
-    name: Optional[str]
-    default: Optional[Any]
+    name: Optional[str] = None
+    default: Optional[Any] = None
     required: bool = False
-    alias: Optional[str]
+    alias: Optional[str] = None
     data_type: DataType
     constraints: Any = None
     strip_default_none: bool = False
@@ -64,12 +82,13 @@ class DataModelFieldBase(_BaseModel):
     const: bool = False
     original_name: Optional[str] = None
     use_default_kwarg: bool = False
+    use_one_literal_as_default: bool = False
     _exclude_fields: ClassVar[Set[str]] = {'parent'}
     _pass_fields: ClassVar[Set[str]] = {'parent', 'data_type'}
 
     if not TYPE_CHECKING:
 
-        def __init__(self, **data: Any):
+        def __init__(self, **data: Any) -> None:
             super().__init__(**data)
             if self.data_type.reference or self.data_type.data_types:
                 self.data_type.parent = self
@@ -84,34 +103,42 @@ class DataModelFieldBase(_BaseModel):
         type_hint = self.data_type.type_hint
 
         if not type_hint:
-            return OPTIONAL
-        elif self.data_type.is_optional and self.data_type.type != 'Any':
+            return NONE
+        elif self.has_default_factory:
+            return type_hint
+        elif self.data_type.is_optional and self.data_type.type != ANY:
             return type_hint
         elif self.nullable is not None:
             if self.nullable:
-                if self.data_type.use_union_operator:
-                    return f'{type_hint} | None'
-                else:
-                    return f'{OPTIONAL}[{type_hint}]'
+                return get_optional_type(type_hint, self.data_type.use_union_operator)
             return type_hint
         elif self.required:
             return type_hint
-        if self.data_type.use_union_operator:
-            return f'{type_hint} | None'
-        else:
-            return f'{OPTIONAL}[{type_hint}]'
+        return get_optional_type(type_hint, self.data_type.use_union_operator)
 
     @property
     def imports(self) -> Tuple[Import, ...]:
+        type_hint = self.type_hint
+        has_union = not self.data_type.use_union_operator and UNION_PREFIX in type_hint
         imports: List[Union[Tuple[Import], Iterator[Import]]] = [
-            self.data_type.all_imports
+            (
+                i
+                for i in self.data_type.all_imports
+                if not (not has_union and i == IMPORT_UNION)
+            )
         ]
+
         if (
             self.nullable or (self.nullable is None and not self.required)
         ) and not self.data_type.use_union_operator:
             imports.append((IMPORT_OPTIONAL,))
         if self.use_annotated:
-            imports.append((IMPORT_ANNOTATED,))
+            import_annotated = (
+                IMPORT_ANNOTATED
+                if self.data_type.python_version.has_annotated_type
+                else IMPORT_ANNOTATED_BACKPORT
+            )
+            imports.append((import_annotated,))
         return chain_as_tuple(*imports)
 
     @property
@@ -143,6 +170,10 @@ class DataModelFieldBase(_BaseModel):
     def annotated(self) -> Optional[str]:
         return None
 
+    @property
+    def has_default_factory(self) -> bool:
+        return 'default_factory' in self.extras
+
 
 @lru_cache()
 def get_template(template_file_path: Path) -> Template:
@@ -217,13 +248,7 @@ class DataModel(TemplateBase, Nullable, ABC):
         if not self.TEMPLATE_FILE_PATH:
             raise Exception('TEMPLATE_FILE_PATH is undefined')
 
-        template_file_path = Path(self.TEMPLATE_FILE_PATH)
-        if custom_template_dir is not None:
-            custom_template_file_path = custom_template_dir / template_file_path.name
-            if custom_template_file_path.exists():
-                template_file_path = custom_template_file_path
-        self._template_file_path = template_file_path
-
+        self._custom_template_dir: Optional[Path] = custom_template_dir
         self.decorators: List[str] = decorators or []
         self._additional_imports: List[Import] = []
         self.custom_base_class = custom_base_class
@@ -282,15 +307,22 @@ class DataModel(TemplateBase, Nullable, ABC):
         return unique_fields
 
     def set_base_class(self) -> None:
-        base_class_import = Import.from_full_path(
-            self.custom_base_class or self.BASE_CLASS
-        )
+        base_class = self.custom_base_class or self.BASE_CLASS
+        if not base_class:
+            self.base_classes = []
+            return None
+        base_class_import = Import.from_full_path(base_class)
         self._additional_imports.append(base_class_import)
         self.base_classes = [BaseClassDataType.from_import(base_class_import)]
 
-    @property
+    @cached_property
     def template_file_path(self) -> Path:
-        return self._template_file_path
+        template_file_path = Path(self.TEMPLATE_FILE_PATH)
+        if self._custom_template_dir is not None:
+            custom_template_file_path = self._custom_template_dir / template_file_path
+            if custom_template_file_path.exists():
+                return custom_template_file_path
+        return template_file_path
 
     @property
     def imports(self) -> Tuple[Import, ...]:
@@ -363,9 +395,9 @@ class DataModel(TemplateBase, Nullable, ABC):
     def path(self) -> str:
         return self.reference.path
 
-    def render(self) -> str:
+    def render(self, *, class_name: Optional[str] = None) -> str:
         response = self._render(
-            class_name=self.class_name,
+            class_name=class_name or self.class_name,
             fields=self.fields,
             decorators=self.decorators,
             base_class=self.base_class,
