@@ -1,11 +1,11 @@
 from __future__ import annotations
 
+from abc import ABC
 from pathlib import Path
-from typing import Any, ClassVar, DefaultDict, Dict, List, Optional, Set, Tuple, Union
+from typing import Any, ClassVar, DefaultDict, Dict, List, Optional, Set, Tuple
 
 from pydantic import Field
 
-from datamodel_code_generator import cached_property
 from datamodel_code_generator.imports import Import
 from datamodel_code_generator.model import (
     ConstraintsBase,
@@ -15,21 +15,21 @@ from datamodel_code_generator.model import (
 from datamodel_code_generator.model.base import UNDEFINED
 from datamodel_code_generator.model.pydantic.imports import IMPORT_EXTRA, IMPORT_FIELD
 from datamodel_code_generator.reference import Reference
-from datamodel_code_generator.types import chain_as_tuple
+from datamodel_code_generator.types import UnionIntFloat, chain_as_tuple
+from datamodel_code_generator.util import cached_property
 
 
 class Constraints(ConstraintsBase):
-    gt: Optional[Union[float, int]] = Field(None, alias='exclusiveMinimum')
-    ge: Optional[Union[float, int]] = Field(None, alias='minimum')
-    lt: Optional[Union[float, int]] = Field(None, alias='exclusiveMaximum')
-    le: Optional[Union[float, int]] = Field(None, alias='maximum')
+    gt: Optional[UnionIntFloat] = Field(None, alias='exclusiveMinimum')
+    ge: Optional[UnionIntFloat] = Field(None, alias='minimum')
+    lt: Optional[UnionIntFloat] = Field(None, alias='exclusiveMaximum')
+    le: Optional[UnionIntFloat] = Field(None, alias='maximum')
     multiple_of: Optional[float] = Field(None, alias='multipleOf')
     min_items: Optional[int] = Field(None, alias='minItems')
     max_items: Optional[int] = Field(None, alias='maxItems')
     min_length: Optional[int] = Field(None, alias='minLength')
     max_length: Optional[int] = Field(None, alias='maxLength')
     regex: Optional[str] = Field(None, alias='pattern')
-    unique_items: Optional[bool] = Field(None, alias='uniqueItems')
 
 
 class DataModelField(DataModelFieldBase):
@@ -50,6 +50,7 @@ class DataModelField(DataModelFieldBase):
     }
     _COMPARE_EXPRESSIONS: ClassVar[Set[str]] = {'gt', 'ge', 'lt', 'le'}
     constraints: Optional[Constraints] = None
+    _PARSE_METHOD: ClassVar[str] = 'parse_obj'
 
     @property
     def method(self) -> Optional[str]:
@@ -92,13 +93,11 @@ class DataModelField(DataModelFieldBase):
         if value is None or constraint not in self._COMPARE_EXPRESSIONS:
             return value
 
-        for data_type in self.data_type.all_data_types:
-            if data_type.type == 'int':
-                value = int(value)
-            else:
-                value = float(value)
-                break
-        return value
+        if any(
+            data_type.type == 'float' for data_type in self.data_type.all_data_types
+        ):
+            return float(value)
+        return int(value)
 
     def _get_default_as_pydantic_model(self) -> Optional[str]:
         for data_type in self.data_type.data_types or (self.data_type,):
@@ -108,19 +107,22 @@ class DataModelField(DataModelFieldBase):
                 continue
             elif data_type.is_list and len(data_type.data_types) == 1:
                 data_type = data_type.data_types[0]
-                data_type.alias
                 if (
                     data_type.reference
                     and isinstance(data_type.reference.source, BaseModel)
                     and isinstance(self.default, list)
                 ):  # pragma: no cover
-                    return f'lambda :[{data_type.alias or data_type.reference.source.class_name}.parse_obj(v) for v in {repr(self.default)}]'
+                    return f'lambda :[{data_type.alias or data_type.reference.source.class_name}.{self._PARSE_METHOD}(v) for v in {repr(self.default)}]'
             elif data_type.reference and isinstance(
                 data_type.reference.source, BaseModel
             ):  # pragma: no cover
-                return f'lambda :{data_type.alias or data_type.reference.source.class_name}.parse_obj({repr(self.default)})'
+                return f'lambda :{data_type.alias or data_type.reference.source.class_name}.{self._PARSE_METHOD}({repr(self.default)})'
         return None
 
+    def _process_data_in_str(self, data: Dict[str, Any]) -> None:
+        if self.const:
+            data['const'] = True
+
     def __str__(self) -> str:
         data: Dict[str, Any] = {
             k: v for k, v in self.extras.items() if k not in self._EXCLUDE_FIELD_KEYS
@@ -143,8 +145,7 @@ class DataModelField(DataModelFieldBase):
         if self.use_field_description:
             data.pop('description', None)  # Description is part of field docstring
 
-        if self.const:
-            data['const'] = True
+        self._process_data_in_str(data)
 
         discriminator = data.pop('discriminator', None)
         if discriminator:
@@ -187,15 +188,12 @@ class DataModelField(DataModelFieldBase):
         return f'Annotated[{self.type_hint}, {str(self)}]'
 
 
-class BaseModel(DataModel):
-    TEMPLATE_FILE_PATH: ClassVar[str] = 'pydantic/BaseModel.jinja2'
-    BASE_CLASS: ClassVar[str] = 'pydantic.BaseModel'
-
+class BaseModelBase(DataModel, ABC):
     def __init__(
         self,
         *,
         reference: Reference,
-        fields: List[DataModelField],
+        fields: List[DataModelFieldBase],
         decorators: Optional[List[str]] = None,
         base_classes: Optional[List[Reference]] = None,
         custom_base_class: Optional[str] = None,
@@ -205,11 +203,11 @@ class BaseModel(DataModel):
         description: Optional[str] = None,
         default: Any = UNDEFINED,
         nullable: bool = False,
-    ):
+    ) -> None:
         methods: List[str] = [field.method for field in fields if field.method]
 
         super().__init__(
-            fields=fields,  # type: ignore
+            fields=fields,
             reference=reference,
             decorators=decorators,
             base_classes=base_classes,
@@ -223,6 +221,58 @@ class BaseModel(DataModel):
             nullable=nullable,
         )
 
+    @property
+    def imports(self) -> Tuple[Import, ...]:
+        if any(f for f in self.fields if f.field):
+            return chain_as_tuple(super().imports, (IMPORT_FIELD,))
+        return super().imports
+
+    @cached_property
+    def template_file_path(self) -> Path:
+        # This property is for Backward compatibility
+        # Current version supports '{custom_template_dir}/BaseModel.jinja'
+        # But, Future version will support only '{custom_template_dir}/pydantic/BaseModel.jinja'
+        if self._custom_template_dir is not None:
+            custom_template_file_path = (
+                self._custom_template_dir / Path(self.TEMPLATE_FILE_PATH).name
+            )
+            if custom_template_file_path.exists():
+                return custom_template_file_path
+        return super().template_file_path
+
+
+class BaseModel(BaseModelBase):
+    TEMPLATE_FILE_PATH: ClassVar[str] = 'pydantic/BaseModel.jinja2'
+    BASE_CLASS: ClassVar[str] = 'pydantic.BaseModel'
+
+    def __init__(
+        self,
+        *,
+        reference: Reference,
+        fields: List[DataModelFieldBase],
+        decorators: Optional[List[str]] = None,
+        base_classes: Optional[List[Reference]] = None,
+        custom_base_class: Optional[str] = None,
+        custom_template_dir: Optional[Path] = None,
+        extra_template_data: Optional[DefaultDict[str, Any]] = None,
+        path: Optional[Path] = None,
+        description: Optional[str] = None,
+        default: Any = UNDEFINED,
+        nullable: bool = False,
+    ) -> None:
+        super().__init__(
+            reference=reference,
+            fields=fields,
+            decorators=decorators,
+            base_classes=base_classes,
+            custom_base_class=custom_base_class,
+            custom_template_dir=custom_template_dir,
+            extra_template_data=extra_template_data,
+            path=path,
+            description=description,
+            default=default,
+            nullable=nullable,
+        )
         config_parameters: Dict[str, Any] = {}
 
         additionalProperties = self.extra_template_data.get('additionalProperties')
@@ -253,22 +303,3 @@ class BaseModel(DataModel):
             from datamodel_code_generator.model.pydantic import Config
 
             self.extra_template_data['config'] = Config.parse_obj(config_parameters)
-
-    @property
-    def imports(self) -> Tuple[Import, ...]:
-        if any(f for f in self.fields if f.field):
-            return chain_as_tuple(super().imports, (IMPORT_FIELD,))
-        return super().imports
-
-    @cached_property
-    def template_file_path(self) -> Path:
-        # This property is for Backward compatibility
-        # Current version supports '{custom_template_dir}/BaseModel.jinja'
-        # But, Future version will support only '{custom_template_dir}/pydantic/BaseModel.jinja'
-        if self._custom_template_dir is not None:
-            custom_template_file_path = (
-                self._custom_template_dir / Path(self.TEMPLATE_FILE_PATH).name
-            )
-            if custom_template_file_path.exists():
-                return custom_template_file_path
-        return super().template_file_path
