@@ -25,10 +25,10 @@ from urllib.parse import ParseResult
 
 from pydantic import BaseModel
 
-from datamodel_code_generator import Protocol, runtime_checkable
 from datamodel_code_generator.format import CodeFormatter, PythonVersion
 from datamodel_code_generator.imports import IMPORT_ANNOTATIONS, Import, Imports
 from datamodel_code_generator.model import pydantic as pydantic_model
+from datamodel_code_generator.model import pydantic_v2 as pydantic_v2_model
 from datamodel_code_generator.model.base import (
     ALL_MODEL,
     UNDEFINED,
@@ -41,6 +41,7 @@ from datamodel_code_generator.model.enum import Enum, Member
 from datamodel_code_generator.parser import DefaultPutDict, LiteralType
 from datamodel_code_generator.reference import ModelResolver, Reference
 from datamodel_code_generator.types import DataType, DataTypeManager, StrictTypes
+from datamodel_code_generator.util import Protocol, runtime_checkable
 
 escape_characters = str.maketrans(
     {
@@ -288,7 +289,7 @@ def _copy_data_types(data_types: List[DataType]) -> List[DataType]:
 
 class Result(BaseModel):
     body: str
-    source: Optional[Path]
+    source: Optional[Path] = None
 
 
 class Source(BaseModel):
@@ -352,6 +353,8 @@ class Parser(ABC):
         field_extra_keys_without_x_prefix: Optional[Set[str]] = None,
         wrap_string_literal: Optional[bool] = None,
         use_title_as_name: bool = False,
+        use_operation_id_as_name: bool = False,
+        use_unique_items_as_set: bool = False,
         http_headers: Optional[Sequence[Tuple[str, str]]] = None,
         http_ignore_tls: bool = False,
         use_annotated: bool = False,
@@ -365,7 +368,8 @@ class Parser(ABC):
         remove_special_field_name_prefix: bool = False,
         capitalise_enum_members: bool = False,
         keep_model_order: bool = False,
-    ):
+        use_one_literal_as_default: bool = False,
+    ) -> None:
         self.data_type_manager: DataTypeManager = data_type_manager_type(
             python_version=target_python_version,
             use_standard_collections=use_standard_collections,
@@ -419,6 +423,8 @@ class Parser(ABC):
         )
         self.current_source_path: Optional[Path] = None
         self.use_title_as_name: bool = use_title_as_name
+        self.use_operation_id_as_name: bool = use_operation_id_as_name
+        self.use_unique_items_as_set: bool = use_unique_items_as_set
 
         if base_path:
             self.base_path = base_path
@@ -474,6 +480,7 @@ class Parser(ABC):
         self.collapse_root_models = collapse_root_models
         self.capitalise_enum_members = capitalise_enum_members
         self.keep_model_order = keep_model_order
+        self.use_one_literal_as_default = use_one_literal_as_default
 
     @property
     def iter_source(self) -> Iterator[Source]:
@@ -481,12 +488,7 @@ class Parser(ABC):
             yield Source(path=Path(), text=self.source)
         elif isinstance(self.source, Path):  # pragma: no cover
             if self.source.is_dir():
-                paths = (
-                    sorted(self.source.rglob('*'))
-                    if self.keep_model_order
-                    else self.source.rglob('*')
-                )
-                for path in paths:
+                for path in sorted(self.source.rglob('*'), key=lambda p: p.name):
                     if path.is_file():
                         yield Source.from_path(path, self.base_path, self.encoding)
             else:
@@ -687,6 +689,42 @@ class Parser(ABC):
                 )
                 models.remove(model)
 
+    @classmethod
+    def _create_set_from_list(cls, data_type: DataType) -> Optional[DataType]:
+        if data_type.is_list:
+            new_data_type = data_type.copy()
+            new_data_type.is_list = False
+            new_data_type.is_set = True
+            for data_type_ in new_data_type.data_types:
+                data_type_.parent = new_data_type
+            return new_data_type
+        elif data_type.data_types:  # pragma: no cover
+            for index, nested_data_type in enumerate(data_type.data_types[:]):
+                set_data_type = cls._create_set_from_list(nested_data_type)
+                if set_data_type:  # pragma: no cover
+                    data_type.data_types[index] = set_data_type
+            return data_type
+        return None  # pragma: no cover
+
+    def __replace_unique_list_to_set(self, models: List[DataModel]) -> None:
+        for model in models:
+            for model_field in model.fields:
+                if not (
+                    isinstance(model_field, pydantic_v2_model.DataModelField)
+                    or self.use_unique_items_as_set
+                ):
+                    continue
+
+                if not (
+                    model_field.constraints and model_field.constraints.unique_items
+                ):
+                    continue
+                set_data_type = self._create_set_from_list(model_field.data_type)
+                if set_data_type:  # pragma: no cover
+                    model_field.data_type.parent = None
+                    model_field.data_type = set_data_type
+                    set_data_type.parent = model_field
+
     @classmethod
     def __set_reference_default_value_to_field(cls, models: List[DataModel]) -> None:
         for model in models:
@@ -936,6 +974,18 @@ class Parser(ABC):
                 models[i], models[i + 1] = models[i + 1], model
                 changed = True
 
+    def __set_one_literal_on_default(self, models: List[DataModel]) -> None:
+        if not self.use_one_literal_as_default:
+            return None
+        for model in models:
+            for model_field in model.fields:
+                if not model_field.required or len(model_field.data_type.literals) != 1:
+                    continue
+                model_field.default = model_field.data_type.literals[0]
+                model_field.required = False
+                if model_field.nullable is not True:  # pragma: no cover
+                    model_field.nullable = False
+
     def parse(
         self,
         with_import: Optional[bool] = True,
@@ -1025,6 +1075,7 @@ class Parser(ABC):
             imports = Imports()
             scoped_model_resolver = ModelResolver()
 
+            self.__replace_unique_list_to_set(models)
             self.__change_from_import(models, imports, scoped_model_resolver, init)
             self.__extract_inherited_enum(models)
             self.__set_reference_default_value_to_field(models)
@@ -1033,6 +1084,7 @@ class Parser(ABC):
             self.__set_default_enum_member(models)
             self.__override_required_field(models)
             self.__sort_models(models, imports)
+            self.__set_one_literal_on_default(models)
 
             processed_models.append(Processed(module, models, init, imports))
 
